@@ -253,9 +253,14 @@ class PhContextFacade(object):
         args = s3.get_object_lines("s3fs-ph-storage", "airflow/dags/phjobs/" + self.path + "/args.properties")
         access_key = os.getenv("AWS_ACCESS_KEY_ID")
         secret_key = os.getenv("AWS_SECRET_ACCESS_KEY")
+        current_user = os.getenv("HADOOP_PROXY_USER")
+        if current_user is None:
+            current_user = "airflow"
         cmd_arr = ["spark-submit",
                    "--master", "yarn",
                    "--deploy-mode", "cluster",
+                   "--name", self.path,
+                   "--proxy-user", current_user,
                    "--conf", "spark.driver.memory=1g",
                    "--conf", "spark.driver.cores=1",
                    "--conf", "spark.executor.memory=2g",
